@@ -2,6 +2,7 @@
 
 /* 
  * Copyright (C) 2002 Sun Microsystems Inc.
+ * Copyright (C) 2005 Elijah Newren
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -77,7 +78,12 @@ meta_bell_flash_screen (MetaDisplay *display,
       XFlush (display->xdisplay);
       XSync (display->xdisplay, False);
       XUnmapWindow (display->xdisplay, screen->flash_window);
+      XFreeGC (display->xdisplay, gc);
     }
+
+  if (meta_prefs_get_focus_mode () != META_FOCUS_MODE_CLICK &&
+      !display->mouse_mode)
+    meta_display_increment_focus_sentinel (display);
   XFlush (display->xdisplay);
 }
 
