@@ -6,6 +6,7 @@
  * Some ICCCM manager selection code derived from fvwm2,
  * Copyright (C) 2001 Dominik Vogt, Matthias Clasen, and fvwm2 team
  * Copyright (C) 2003 Rob Adams
+ * Copyright (C) 2004 Elijah Newren
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -735,6 +736,9 @@ meta_screen_free (MetaScreen *screen)
   XFreeGC (screen->display->xdisplay,
            screen->root_xor_gc);
   
+  if (screen->xinerama_infos)
+    g_free (screen->xinerama_infos);
+  
   g_free (screen->screen_name);
   g_free (screen);
 
@@ -1152,6 +1156,18 @@ meta_screen_set_cursor (MetaScreen *screen,
   XFreeCursor (screen->display->xdisplay, xcursor);
 }
 
+void
+meta_screen_update_cursor (MetaScreen *screen)
+{
+  Cursor xcursor;
+
+  xcursor = meta_display_create_x_cursor (screen->display, 
+					  screen->current_cursor);
+  XDefineCursor (screen->display->xdisplay, screen->xroot, xcursor);
+  XFlush (screen->display->xdisplay);
+  XFreeCursor (screen->display->xdisplay, xcursor);
+}
+
 void
 meta_screen_ensure_tab_popup (MetaScreen *screen,
                               MetaTabList type)
@@ -1190,7 +1206,7 @@ meta_screen_ensure_tab_popup (MetaScreen *screen,
       entries[i].title = window->title;
       entries[i].icon = window->icon;
       entries[i].blank = FALSE;
-      entries[i].minimized = !meta_window_showing_on_its_workspace (window);
+      entries[i].hidden = !meta_window_showing_on_its_workspace (window);
       entries[i].demands_attention = window->wm_state_demands_attention;
       
       if (!window->minimized || !meta_window_get_icon_geometry (window, &r))
@@ -1294,7 +1310,7 @@ meta_screen_ensure_workspace_popup (MetaScreen *screen)
           entries[i].icon = NULL;
           entries[i].blank = TRUE;
         }
-      entries[i].minimized = FALSE;
+      entries[i].hidden = FALSE;
       entries[i].demands_attention = FALSE;
 
       ++i;
